[![Docs](https://readthedocs.org/projects/ai2-climate-emulator/badge/?version=latest)](https://ai2-climate-emulator.readthedocs.io/en/latest/)
[![PyPI](https://img.shields.io/pypi/v/fme.svg)](https://pypi.org/project/fme/)

# FME: Weather/Climate Model Emulation
This package contains code to train and evaluate weather/climate model emulators.

## Installation

The package can be installed via PyPI using:

```
pip install fme
```

## Quickstart

A quickstart guide may be found [here](https://ai2-climate-emulator.readthedocs.io/en/latest/quickstart.html).

## Documentation

See complete documentation [here](https://ai2-climate-emulator.readthedocs.io/en/latest/).
